@@ -6,13 +6,11 @@ import time
 import warnings
 from datetime import datetime
 
-from attrs import asdict, fields, filters
 from django.conf import settings
 from django.core.management.base import BaseCommand
 from django.db import connection
 from edx_django_utils.monitoring import record_exception, set_custom_attribute
 from edx_toggles.toggles import SettingToggle
-from openedx_events.data import EventsMetadata
 from openedx_events.event_bus.avro.deserializer import AvroSignalDeserializer
 from openedx_events.tooling import OpenEdxPublicSignal
 
@@ -356,13 +354,10 @@ class KafkaEventConsumer:
                 f"Received message of type {event_type_str}."
             )
         try:
-            event_metadata = asdict(_get_metadata_from_headers(headers),
-                                    # don't pass the event_type along since send_with_custom_metadata doesn't use it
-                                    # and will raise if it's present
-                                    filter=filters.exclude(fields(EventsMetadata).event_type))
+            event_metadata = _get_metadata_from_headers(headers)
         except Exception as e:
             raise UnusableMessageError(f"Error determining metadata from message headers: {e}") from e
-        send_results = self.signal.send_event_with_custom_metadata(**event_metadata, **msg.value())
+        send_results = self.signal.send_event_with_custom_metadata(event_metadata, **msg.value())
         # Raise an exception if any receivers errored out. This allows logging of the receivers
         # along with partition, offset, etc. in record_event_consuming_error. Hopefully the
         # receiver code is idempotent and we can just replay any messages that were involved.
